function [ X1, t, f] = spectrogramTZ(x,Nwind,Noverlap,Nfft,fs,option)
% INPUT:
% x - signal to analyze
% Nwind    - window length
% Noverlap - window overlap
% Nfft     - FFT size >= Nwind
% fs - sampling frequency
% OUTPUT:
% X1 = STFT(t,f) [V (dB)]

% In Matlab and Octave:
% [X,f,t] = spectrogram(x,Nwin,Nover,Nfft,fs);      % STFT in Matlab (new)
% [X,f,t] = specgram(x,Nfft,fs,Nwin,Nover);         % STFT in Octave and Matlab (old)

dt = 1/fs;                                          % sampling period
N = length(x);                                      % signal length
Nstep = Nwind-Noverlap;                             % window shift
Nspec = floor((N-Nwind)/Nstep)+1;                   % number of STFT spectra 
t = (Nwind/2+1/2)*dt + Nstep*dt*(0:Nspec-1);        % time
f = fs/Nfft*(0:Nfft-1);                             % frequency    
w = hamming( Nwind )';                              % window choice
X1 = zeros(Nfft,Nspec);                             % STFT initialization 
%X2 = zeros(1,Nfft);                                % PSD initialization 
for m = 1 : Nspec                                   % processing loop
    bx = x( 1+(m-1)*Nstep : Nwind+(m-1)*Nstep );    % signal fragment 
    bx = bx .* w;                                   % windowing
    X = fft( bx, Nfft )/sum(w);                     % FFT with scaling
    X1(1:Nfft,m) = X;                               % STFT
  % X2 = X2 + abs(X).^2;                            % Welch PSD
end                                                 % loop end
X1 = 20*log10( abs(X1) );                           % to decibels
%X2 = (1/Nspec)*X2/fs;                              % PSD normalization

imagesc(t,f,X1);      % amplitude spectrum matrix as an image
cb=colorbar('location','EastOutside'); set( get(cb,'Ylabel'),'String','V (dB)');
xlabel('time (s)'); ylabel('frequency (Hz)');

% semilogy(f,X2); grid; title('Welch estimation of PSD'); xlabel('f [Hz]'); ylabel('V^2 / Hz');
